package ecp.vcs.com.ecpsyncplugin.re_sync.logging;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.json.JSONTokener;

import java.io.IOException;

import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okio.Buffer;

/**
 * Created by CHANDAN KUSHWAHA on 25/01/2019.
 * Class For Intercepting Log of Requests and Response
 */

public class LogJsonInterceptor implements Interceptor {

    @Override
    public Response intercept(Chain chain) throws IOException {
        Request request = chain.request();
        Response response = chain.proceed(request);
        String rawJson = response.body().string();
        LogHelper.printLog("LOG_INTERCEPTOR", rawJson);
        try {
            String requestLog = String.format("Sending request %s on %s%n%s", request.url(), request.headers(), bodyToString(request.body()));
            LogHelper.printLog("LOG_INTERCEPTOR", requestLog);

            if (isJSONValid(rawJson)) {
                Object object = new JSONTokener(rawJson).nextValue();
                String jsonLog = object instanceof JSONObject
                        ? ((JSONObject) object).toString(4)
                        : ((JSONArray) object).toString(4);
                LogHelper.printLog("LOG_INTERCEPTOR", jsonLog);
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }

        // Re-create the response before returning it because body can be read only once
        return response.newBuilder().body(ResponseBody.create(response.body().contentType(), rawJson)).build();
    }

    public boolean isJSONValid(String test) {
        try {
            new JSONObject(test);
        } catch (JSONException ex) {
            try {
                new JSONArray(test);
            } catch (JSONException ex1) {
                return false;
            }
        }
        return true;
    }

    public static String bodyToString(final RequestBody request) {
        try {
            final Buffer buffer = new Buffer();
            if (request != null)
                request.writeTo(buffer);
            else
                return "";
            return buffer.readUtf8();
        } catch (final IOException e) {
            return "did not work";
        }
    }
}
